@@ -45,8 +45,7 @@ pub fn from_continuous(sample_data: &[u8],
 ///
 /// The samples will internaly be copied to a single continuous buffer,
 /// so make sure you have enough memory available.
-pub fn from_samples<S: AsRef<[u8]>>(samples: &[S],
-                                    max_size: usize) -> io::Result<Vec<u8>> {
+pub fn from_samples<S: AsRef<[u8]>>(samples: &[S], max_size: usize) -> io::Result<Vec<u8>> {
     // Copy every sample to a big chunk of memory
     let data: Vec<_> = samples.iter()
                               .flat_map(|s| s.as_ref())
